% PLOT_MEMORY   Generates the memory usage plots.
%   Before calling this script, assign a scalar integer into
%   the YAXISDATA variable to select which data to plot:
%      yaxisdata = 2; % Plots RSS, resident set size.
%      yaxisdata = 3; % Plots VSZ, virtual memory size.

% (c)2008-2009, Cris Luengo, Centre for Image Analysis, Uppsala, Sweden.
% GNU GPL v.3.0 -- see gpl-3.0.txt

% What part of the results to plot
min_y = 3e2;
max_y = 5e6;

% Which algorithms to not show
toremove = [1,2,4,8,10,11];

% --- End of config ---

results_memory

plotlabels
data(toremove) = [];
labels(toremove,:) = [];
col = labels(:,1);
N = length(data);
if N>length(col)
   error('Add more entries to LABELS!')
end

figure, set(gcf,'position',figpos)
box on, hold on
set(gca,'position',[0.11,0.11,0.85,0.86])
set(gca,'fontsize',fontsize,'linewidth',1)
set(gca,'xscale','log','xlim',[1,max(data0(:,1))],'xtick',10.^(0:8))
set(gca,'yscale','log','ylim',[min_y,max_y])

lh = zeros(N,1);
for ii=1:N
   x = data{ii}(:,1);
   y = data{ii}(:,yaxisdata);
   if x(2)==3 % high density plots
      h = plot(x,y,col{ii}([1,3:end]),'linewidth',1); % no marker
      darkencolor(h)
      h = plot(x(3:3:end),y(3:3:end),col{ii}(1:2),'linewidth',1); % no line
      darkencolor(h)
      lh(ii) = plot(1e-4,1e-4,col{ii},'linewidth',1);
   else
      lh(ii) = plot(x,y,col{ii},'linewidth',1);
   end
   darkencolor(lh(ii))
end

xlabel('Number of elements on the stack')
ylabel('Memory usage (KiB)')
legend(lh,labels(:,2),'location','northwest');

% Model
data0(:,yaxisdata) = mean(data0(:,yaxisdata));
data0(1,1) = 1; % Instead of 2, this way the line extends all the way to the left of the graph.
plot(data0(:,1),data0(:,yaxisdata)+data0(:,1)*16/1024,'k--','linewidth',1);
plot(data0(:,1),data0(:,1)*16/1024,'k--','linewidth',1);
plot(data0(:,1),data0(:,yaxisdata),'k--','linewidth',1);

if yaxisdata==2
   print -deps2c -r300 -loose memory_rss.eps
else
   print -deps2c -r300 -loose memory_vsz.eps
end
