% PLOT_SPEED   Generates the hold speed plots.
%   Before calling this script, assign a string into the
%   COMPSTR variable to select which data to plot:
%      compstr = ''
%      compstr = 'solaris'
%      compstr = 'solaris_gcc'
%      compstr = 'opteron'

% (c)2008-2009, Cris Luengo, Centre for Image Analysis, Uppsala, Sweden.
% GNU GPL v.3.0 -- see gpl-3.0.txt

% What part of the results to plot
indx = 2:12;
min_x = 5e2;
max_x = 1e8;
max_y = 3;

% 2nd plot: what to keep
[bla,indx2] = intersect(indx,[3,4,5,9,11,12]);
min2_x = 2;
max2_x = 1e5;
max2_y = 0.3;

switch compstr
   case 'opteron'
      max_y = 3.5;
      max2_y = 0.35;
   case 'solaris'
      min_x = 1e2;
      max_x = 2e7;
      max_y = 6;
      max2_y = 1;
   case 'solaris_gcc'
      min_x = 1e2;
      max_x = 2e7;
      max_y = 9;
      max2_y = 1;
end

% --- End of config ---

rescmd = 'results_speed1';
basefname = 'speed';
if ~isempty(compstr)
   rescmd = [rescmd,'_',compstr];
   basefname = [basefname,'_',compstr];
end
eval(rescmd);
data = data(indx);
datacol = 3;

plotlabels
labels = labels(indx,:);
col = labels(:,1);
N = length(data);
if N>length(col)
   error('Add more entries to LABELS!')
end

figure, set(gcf,'position',figpos)
box on, hold on
set(gca,'position',[0.11,0.11,0.85,0.86])
set(gca,'fontsize',fontsize,'linewidth',1)
set(gca,'xscale','log','xlim',[min_x,max_x],'xtick',10.^(0:8),'ylim',[0,max_y])

base = mean(data0(:,datacol));
h = zeros(N,1);
for ii=1:N
   x = data{ii}(:,1);
   y = (data{ii}(:,datacol)-base) * 1e6/Niter;
   h(ii) = plot(x,y,col{ii},'linewidth',1);
   darkencolor(h(ii))
end

xlabel('Number of elements on the stack')
ylabel('Time it takes to do one hold operation (\mus)')
legend(labels(:,2),'location','northwest');

print('-deps2c','-r300','-loose',[basefname,'.eps'])

% 2nd plot

set(gca,'xlim',[min2_x,max2_x],'ylim',[0,max2_y])

d = 1:N;
d(indx2) = [];
delete(h(d));
legend(labels(indx2,2),'location','northwest');

print('-deps2c','-r300','-loose',[basefname,'_small.eps'])
