% PLOT_SPEED_ENQUEUE   Generates the queue building speed plots.
%   Before calling this script, assign a string into the
%   COMPSTR variable to select which data to plot:
%      compstr = ''
%      compstr = 'solaris'
%      compstr = 'solaris_gcc'
%      compstr = 'opteron'
%   Also define the ENQUEUE variable, and set it to TRUE or FALSE,
%   to plot enqueue or dequeue speeds, respectively.

% (c)2008-2009, Cris Luengo, Centre for Image Analysis, Uppsala, Sweden.
% GNU GPL v.3.0 -- see gpl-3.0.txt

% What part of the results to plot
if enqueue
   max_y = 3;   % micro seconds
else
   max_y = 1.3;   % micro seconds
end
min_x = 1e5;
max_x = 1e8;

indx = [3,4,5,7,9,10,11,12];

switch compstr
   case {'solaris','solaris_gcc'}
      if enqueue
         max_y = 7;   % micro seconds
      else
         max_y = 4;   % micro seconds
      end
      min_x = 2e4;
      max_x = 2e7;
      indx = [3,4,5,8,9,10,11,12];
end

if enqueue
   datacol = 2;
   dirstr = 'enqueue';
else
   datacol = 4;
   dirstr = 'dequeue';
end

% --- End of config ---

basefname = 'speed';
rescmd = 'results_speed1';
if ~isempty(compstr)
   basefname = [basefname,'_',compstr];
   rescmd = [rescmd,'_',compstr];
end
basefname = [basefname,'_',dirstr];
eval(rescmd);
data = data(indx);

plotlabels
labels = labels(indx,:);
col = labels(:,1);
N = length(data);
if N>length(col)
   error('Add more entries to LABELS!')
end

figure, set(gcf,'position',figpos)
box on, hold on
set(gca,'position',[0.11,0.11,0.85,0.86])
set(gca,'fontsize',fontsize,'linewidth',1)
set(gca,'xscale','log','xlim',[min_x,max_x],'ylim',[0,max_y])

base = data0(:,datacol);
I = base > 0.02;
base = data0(:,datacol)./data0(:,1);
base = mean(base(I));
h = zeros(N,1);
for ii=1:N
   x = data{ii}(:,1);
   y = data{ii}(:,datacol);
   I = y > 0.02;
   x = x(I);
   y = (y(I)./x - base) * 1e6;
   h(ii) = plot(x,y,col{ii},'linewidth',1);
   darkencolor(h(ii))
end

xlabel('Number of elements on the stack')
ylabel(['Average time it takes to ',dirstr,' each item (\mus)'])
legend(labels(:,2),'location','northwest');

print('-deps2c','-r300','-loose',[basefname,'.eps'])
