% PLOT_SPEED_VS_MEMORY   Generates the hold speed vs memory usage plot.

% (c)2008-2009, Cris Luengo, Centre for Image Analysis, Uppsala, Sweden.
% GNU GPL v.3.0 -- see gpl-3.0.txt

% Which algorithms to not show
toremove = [1,2,6,7,8,11,12];

% Which algorithms to do fitting on
tofit1 = [3,4,9,10];
tofit2 = [5];

% Which data column from the memory results to take
% 2 = RSS = resident set size (in KiB).
% 3 = VSZ = virtual memory size (in KiB).
memcol = 2;

% What part of the results to plot
xlim = 10;   % minimum value along x axis.
ylim = 0.07; % minimum value along y axis.

cachesize = 6144; % in KiB

% --- End of config ---

results_memory
mem = data;
mem(toremove) = [];
basemem = mean(data0(:,memcol));
results_speed1
N = length(data);
data(toremove) = [];
datacol = 3;

tmp = zeros(1,N);
tmp(tofit1) = 1;
tmp(toremove) = [];
tofit1 = find(tmp);

tmp = zeros(1,N);
tmp(tofit2) = 1;
tmp(toremove) = [];
tofit2 = find(tmp);

max_x = 0;
min_x = inf;
max_y = 0;
min_y = inf;
for ii=1:length(data);
   if isequal(data{ii}(:,1),mem{ii}(:,1))
      data{ii}(:,1) = mem{ii}(:,memcol) - basemem;
   else
      data{ii}(:,1) = interp1(mem{ii}(:,1),mem{ii}(:,memcol),data{ii}(:,1)) - basemem;
   end
   m = data{ii}(:,1)>0;
   data{ii} = data{ii}(m,:);
   m = min(data{ii}(:,1));
   m = find(data{ii}(:,1) == m);
   m = m(end);
   data{ii} = data{ii}(m:end,:);
   max_x = max(max_x,max(data{ii}(:,1)));
   min_x = min(min_x,min(data{ii}(:,1)));
   max_y = max(max_y,max(data{ii}(:,datacol)));
   min_y = min(min_y,min(data{ii}(:,datacol)));
end
min_y = ylim(1);
max_y = max_y * 1e6/Niter;
min_x = xlim(1);

ytick = [min_y:0.01:0.1,0.2:0.1:1,2:1:10];
ytick = round(ytick*100)/100; % so that one of these actually is 0.3!
yticklabel = cell(size(ytick));
yticklabel{ytick==0.1} = 0.1;
yticklabel{ytick==0.3} = 0.3;
yticklabel{ytick==1} = 1;
yticklabel{ytick==3} = 3;

plotlabels
   % some changes...
   labels{2,1}(2) = 's';
   labels{10,1}(2) = 'v';
   labels{11,1}(2) = '>';
labels(toremove,:) = [];
col = labels(:,1);
N = length(data);
if N>length(col)
   error('Add more entries to LABELS!')
end

figure, set(gcf,'position',figpos)
box on, hold on
set(gca,'position',[0.11,0.11,0.85,0.86])
set(gca,'fontsize',fontsize,'linewidth',1)
set(gca,'xscale','log','xlim',[min_x,max_x])
set(gca,'yscale','log','ylim',[min_y,max_y],'ytick',ytick,'yticklabel',yticklabel);

for ii=1:N
   h = plot([1e-3,1e-2],[1e-3,1e-2],col{ii},'linewidth',1);
   darkencolor(h)
end

xlabel('Memory usage (KiB)')
ylabel('Time it takes to do one hold operation (\mus)')
legend(labels(:,2),'location','northwest');

plot([cachesize,cachesize],[min_y,max_y],'k--','linewidth',1);
text(cachesize*1.1,ylim(1)*1.8,['cache size = ',num2str(cachesize),' KiB'],'fontsize',fontsize);

base = mean(data0(:,datacol));
for ii=1:N
   data{ii}(:,datacol) = (data{ii}(:,datacol)-base) * 1e6/Niter;
   x = data{ii}(:,1);
   y = data{ii}(:,datacol);
   h = plot(x,y,col{ii},'linewidth',1);
   set(h,'linestyle','none');
   darkencolor(h)
end

for ii=tofit1

   x = data{ii}(:,1);
   y = data{ii}(:,datacol);

   m = x<cachesize;
   I = find(diff(x)<=0);
   if ~isempty(I)
      m(1:I(end)) = 0;
   end
   p = polyfit(log(x(m)),y(m),1);
   x1 = x(m);
   x1 = logspace(log10(x1(1)),log10(cachesize),100);
   y1 = polyval(p,log(x1));

   h = plot(x1,y1,col{ii},'linewidth',1);
   set(h,'marker','none');
   darkencolor(h)

   m = x>cachesize;
   p = polyfit(log(x(m)),y(m),1);
   x2 = x(m);
   x2 = logspace(log10(cachesize),log10(x2(end)*1.3),100);
   y2 = polyval(p,log(x2));

   h = plot(x2,y2,col{ii},'linewidth',1);
   set(h,'marker','none');
   darkencolor(h)

end

for ii=tofit2

   x = data{ii}(:,1);
   y = data{ii}(:,datacol);
   I = find(diff(x)<=0);
   if ~isempty(I)
      x(1:I(end)) = [];
      y(1:I(end)) = [];
   end
   p = polyfit(log(x),y,1);
   x = logspace(log10(x(1)),log10(x(end)*1.3),100);
   y = polyval(p,log(x));

   h = plot(x,y,col{ii},'linewidth',1);
   set(h,'marker','none');
   darkencolor(h)

end

print -deps2c -r300 -loose speed_vs_memory.eps
